@@ -1,5 +1,5 @@
 #    Back In Time
-#    Copyright (C) 2012-2016 Germar Reitze
+#    Copyright (C) 2012-2017 Germar Reitze
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -28,9 +28,9 @@ with open(os.path.join(PATH, '../VERSION'), 'r') as f:
     VERSION = f.read().strip('\n')
 SORT = True #True = sort by alphabet; False = sort by line numbering
 
-c_list = re.compile(r'.*?self\.get((?:_profile)?)_(list)_value ?\( ?[\'"](.*?)[\'"], ?((?:\(.*\)|[^,]*)), ?[\'"]?([^\'",\)]*)[\'"]?')
-c =      re.compile(r'.*?self\.get((?:_profile)?)_(.*?)_value ?\( ?[\'"](.*?)[\'"] ?(%?[^,]*?), ?[\'"]?([^\'",\)]*)[\'"]?')
-c_default = re.compile(r'(^DEFAULT[\w]*)[\s]*= (.*)')
+c_list = re.compile(r'.*?self\.(?!set)((?:profile)?)(List)Value ?\( ?[\'"](.*?)[\'"], ?((?:\(.*\)|[^,]*)), ?[\'"]?([^\'",\)]*)[\'"]?')
+c =      re.compile(r'.*?self\.(?!set)((?:profile)?)(.*?)Value ?\( ?[\'"](.*?)[\'"] ?(%?[^,]*?), ?[\'"]?([^\'",\)]*)[\'"]?')
+c_default = re.compile(r'(^DEFAULT[\w]*|CONFIG_VERSION)[\s]*= (.*)')
 
 HEADER = '''.TH backintime-config 1 "%s" "version %s" "USER COMMANDS"
 .SH NAME
@@ -41,7 +41,7 @@ config \- BackInTime configuration files.
 /etc/backintime/config
 .SH DESCRIPTION
 Back In Time was developed as pure GUI program and so most functions are only
-useable with backintime-qt4. But it is possible to use
+useable with backintime-qt. But it is possible to use
 Back In Time e.g. on a headless server. You have to create the configuration file
 (~/.config/backintime/config) manually. Look inside /usr/share/doc/backintime\-common/examples/ for examples.
 .PP
@@ -56,7 +56,7 @@ Run 'backintime check-config' to verify the configfile, create the snapshot fold
 ''' % (strftime('%b %Y', gmtime()), VERSION)
 
 FOOTER = '''.SH SEE ALSO
-backintime, backintime-qt4.
+backintime, backintime-qt.
 .PP
 Back In Time also has a website: https://github.com/bit-team/backintime
 .SH AUTHOR
@@ -76,7 +76,7 @@ def output(instance = '', name = '', values = '', default = '', comment = '', re
         default = "''"
     ret  = '.IP "\\fI%s\\fR" 6\n' % name
     ret += '.RS\n'
-    ret += 'Type: %-10sAllowed Values: %s\n' %(instance, values)
+    ret += 'Type: %-10sAllowed Values: %s\n' %(instance.lower(), values)
     ret += '.br\n'
     ret += '%s\n' % comment
     ret += '.PP\n'
@@ -95,17 +95,17 @@ def select(a, b):
 def select_values(instance, values):
     if values:
         return values
-    if instance == 'bool':
+    if instance.lower() == 'bool':
         return 'true|false'
-    if instance == 'str':
+    if instance.lower() == 'str':
         return 'text'
-    if instance == 'int':
+    if instance.lower() == 'int':
         return '0-99999'
 
 def process_line(d, key, profile, instance, name, var, default, commentline, values, force_var, force_default, replace_default, counter):
     #Ignore commentlines with #?! and 'config.version'
     comment = None
-    if not commentline.startswith('!') and not name == 'config.version' and not key in d:
+    if not commentline.startswith('!') and not key in d:
         d[key] = {}
         commentline = commentline.split(';')
         try:
@@ -122,7 +122,7 @@ def process_line(d, key, profile, instance, name, var, default, commentline, val
         if isinstance(force_default, str) and force_default.startswith('self.') and force_default[5:] in replace_default:
             force_default = replace_default[force_default[5:]]
 
-        if instance == 'bool':
+        if instance.lower() == 'bool':
             default = default.lower()
         d[key][INSTANCE]  = instance
         d[key][NAME]      = re.sub(r'%[\S]', '<%s>' % select(force_var, var).upper(), name)
@@ -141,21 +141,21 @@ def main():
                              DEFAULT   : '1',
                              COMMENT   : 'Internal version of profiles config.',
                              REFERENCE : 'configfile.py',
-                             LINE      : 180}
+                             LINE      : 419}
     d['profiles'] = {INSTANCE  : 'str',
                      NAME      : 'profiles',
                      VALUES    : 'int separated by colon (e.g. 1:3:4)',
                      DEFAULT   : '1',
                      COMMENT   : 'All active Profiles (<N> in profile<N>.snapshots...).',
                      REFERENCE : 'configfile.py',
-                     LINE      : 273}
+                     LINE      : 472}
     d['profile<N>.name'] = {INSTANCE  : 'str',
                             NAME      : 'profile<N>.name',
                             VALUES    : 'text',
                             DEFAULT   : 'Main profile',
                             COMMENT   : 'Name of this profile.',
                             REFERENCE : 'configfile.py',
-                            LINE      : 246}
+                            LINE      : 704}
     with open(CONFIG, 'r') as f:
         commentline = ''
         values = force_var = force_default = instance = name = var = default = None
@@ -180,10 +180,10 @@ def main():
                 m = c.match(line)
             if m:
                 profile, instance, name, var, default = m.groups()
-                if profile == '_profile':
+                if profile == 'profile':
                     name = 'profile<N>.' + name
                 var = var.lstrip('% ')
-                if instance == 'list':
+                if instance.lower() == 'list':
                     type_key = [x.strip('"\'') for x in re.findall(r'["\'].*?["\']', var)]
                     commentline_split = commentline.split('::')
                     for i, tk in enumerate(type_key):
@@ -208,5 +208,5 @@ def main():
         f.write('\n'.join(output(**d[key]) for key in sorted(d, key = s)))
         f.write(FOOTER)
 
-if __name__ == "__main__":
+if __name__ == '__main__':
     main()
