@@ -1,4 +1,4 @@
-#    Copyright (C) 2015 Germar Reitze
+#    Copyright (C) 2015-2017 Germar Reitze
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -18,18 +18,18 @@ import unittest
 import os
 import sys
 import itertools
+from test import generic
 
 sys.path.append(os.path.join(os.path.dirname(__file__), ".."))
 import backintime
-import logger
 
 def shuffleArgs(*args):
-    '''
+    """
     Return every possible combination of arguments. Those arguments which need
     to keep in line have to be inside a tuple.
 
     args:   two or more arguments (str)
-    '''
+    """
     for i in itertools.permutations(args):
         ret = []
         for j in i:
@@ -39,53 +39,53 @@ def shuffleArgs(*args):
                 ret.append(j)
         yield ret
 
-class TestArgParser(unittest.TestCase):
+class TestArgParser(generic.TestCase):
     def setUp(self):
-        #import pdb; pdb.set_trace()
-        backintime.create_parsers()
-        logger.DEBUG = '-v' in sys.argv #False
+        super(TestArgParser, self).setUp()
+        backintime.createParsers()
 
     def tearDown(self):
+        super(TestArgParser, self).tearDown()
         global parsers
         parsers = {}
 
     def test_invalid_arg(self):
         with self.assertRaises(SystemExit):
-            backintime.arg_parse(['not_existing_command'])
+            backintime.argParse(['not_existing_command'])
         with self.assertRaises(SystemExit):
-            backintime.arg_parse(['--not_existing_argument'])
+            backintime.argParse(['--not_existing_argument'])
 
     def test_config(self):
-        args = backintime.arg_parse(['--config', '/tmp/config'])
+        args = backintime.argParse(['--config', '/tmp/config'])
         self.assertIn('config', args)
         self.assertEqual(args.config, '/tmp/config')
 
     def test_quiet(self):
-        args = backintime.arg_parse(['--quiet',])
+        args = backintime.argParse(['--quiet',])
         self.assertIn('quiet', args)
         self.assertTrue(args.quiet)
 
     def test_debug(self):
-        args = backintime.arg_parse(['--debug',])
+        args = backintime.argParse(['--debug',])
         self.assertIn('debug', args)
         self.assertTrue(args.debug)
 
     def test_config_no_path(self):
         with self.assertRaises(SystemExit):
-            backintime.arg_parse(['--config'])
+            backintime.argParse(['--config'])
 
     ############################################################################
     ###                               Backup                                 ###
     ############################################################################
     def test_cmd_backup(self):
-        args = backintime.arg_parse(['backup'])
+        args = backintime.argParse(['backup'])
         self.assertIn('command', args)
         self.assertEqual(args.command, 'backup')
         self.assertIn('func', args)
         self.assertIs(args.func, backintime.backup)
 
     def test_cmd_backup_backwards_compatiblity_alias(self):
-        args = backintime.arg_parse(['--backup'])
+        args = backintime.argParse(['--backup'])
         self.assertIn('func', args)
         self.assertIs(args.func, backintime.aliasParser)
         self.assertIn('replace', args)
@@ -98,14 +98,14 @@ class TestArgParser(unittest.TestCase):
             with self.subTest(argv = argv):
                 #workaround for py.test3 2.5.1 doesn't support subTest
                 msg = 'argv = %s' %argv
-                args = backintime.arg_parse(argv)
+                args = backintime.argParse(argv)
                 self.assertIn('command', args, msg)
                 self.assertEqual(args.command, 'backup', msg)
                 self.assertIn('profile', args, msg)
                 self.assertEqual(args.profile, 'foo', msg)
 
     def test_cmd_backup_profile_id(self):
-        args = backintime.arg_parse(['backup', '--profile-id', '2'])
+        args = backintime.argParse(['backup', '--profile-id', '2'])
         self.assertIn('command', args)
         self.assertEqual(args.command, 'backup')
         self.assertIn('profile_id', args)
@@ -113,10 +113,10 @@ class TestArgParser(unittest.TestCase):
 
     def test_cmd_backup_profile_and_profile_id(self):
         with self.assertRaises(SystemExit):
-            backintime.arg_parse(['backup', '--profile', 'foo', '--profile-id', '2'])
+            backintime.argParse(['backup', '--profile', 'foo', '--profile-id', '2'])
 
     def test_cmd_backup_quiet(self):
-        args = backintime.arg_parse(['backup', '--quiet'])
+        args = backintime.argParse(['backup', '--quiet'])
         self.assertIn('command', args)
         self.assertEqual(args.command, 'backup')
         self.assertIn('quiet', args)
@@ -128,7 +128,7 @@ class TestArgParser(unittest.TestCase):
             with self.subTest(argv = argv):
                 #workaround for py.test3 2.5.1 doesn't support subTest
                 msg = 'argv = %s' %argv
-                args = backintime.arg_parse(argv)
+                args = backintime.argParse(argv)
                 self.assertIn('command', args, msg)
                 self.assertEqual(args.command, 'backup', msg)
                 self.assertIn('profile', args, msg)
@@ -144,14 +144,14 @@ class TestArgParser(unittest.TestCase):
     ###                               Restore                                ###
     ############################################################################
     def test_cmd_restore(self):
-        args = backintime.arg_parse(['restore'])
+        args = backintime.argParse(['restore'])
         self.assertIn('command', args)
         self.assertEqual(args.command, 'restore')
         self.assertIn('func', args)
         self.assertIs(args.func, backintime.restore)
 
     def test_cmd_restore_what_where_snapshot_id(self):
-        args = backintime.arg_parse(['restore', '/home', '/tmp', '20151130-230501-984'])
+        args = backintime.argParse(['restore', '/home', '/tmp', '20151130-230501-984'])
         self.assertIn('command', args)
         self.assertEqual(args.command, 'restore')
         self.assertIn('WHAT', args)
@@ -168,7 +168,7 @@ class TestArgParser(unittest.TestCase):
             with self.subTest(argv = argv):
                 #workaround for py.test3 2.5.1 doesn't support subTest
                 msg = 'argv = %s' %argv
-                args = backintime.arg_parse(argv)
+                args = backintime.argParse(argv)
                 self.assertIn('quiet', args, msg)
                 self.assertTrue(args.quiet, msg)
                 self.assertIn('checksum', args, msg)
@@ -197,7 +197,7 @@ class TestArgParser(unittest.TestCase):
             with self.subTest(argv = argv):
                 #workaround for py.test3 2.5.1 doesn't support subTest
                 msg = 'argv = %s' %argv
-                args = backintime.arg_parse(argv)
+                args = backintime.argParse(argv)
                 self.assertIn('quiet', args, msg)
                 self.assertTrue(args.quiet, msg)
                 self.assertIn('checksum', args, msg)
@@ -214,28 +214,28 @@ class TestArgParser(unittest.TestCase):
                 self.assertEqual(args.config, 'foo', msg)
 
     def test_cmd_restore_snapshot_id_index(self):
-        args = backintime.arg_parse(['restore', '/home', '/tmp', '1'])
+        args = backintime.argParse(['restore', '/home', '/tmp', '1'])
         self.assertIn('SNAPSHOT_ID', args)
         self.assertEqual(args.SNAPSHOT_ID, '1')
 
     def test_cmd_restore_empty_where(self):
-        args = backintime.arg_parse(['restore', '/home', '', '20151130-230501-984'])
+        args = backintime.argParse(['restore', '/home', '', '20151130-230501-984'])
         self.assertIn('WHERE', args)
         self.assertEqual(args.WHERE, '')
 
     def test_cmd_restore_where_space_in_path(self):
-        args = backintime.arg_parse(['restore', '/home', '/tmp/foo bar/baz', '20151130-230501-984'])
+        args = backintime.argParse(['restore', '/home', '/tmp/foo bar/baz', '20151130-230501-984'])
         self.assertIn('WHERE', args)
         self.assertEqual(args.WHERE, '/tmp/foo bar/baz')
 
     def test_cmd_restore_what_space_in_path(self):
-        args = backintime.arg_parse(['restore', '/home/foo bar/baz', '/tmp', '20151130-230501-984'])
+        args = backintime.argParse(['restore', '/home/foo bar/baz', '/tmp', '20151130-230501-984'])
         self.assertIn('WHAT', args)
         self.assertEqual(args.WHAT, '/home/foo bar/baz')
 
     def test_cmd_restore_local_backup_and_no_local_backup(self):
         with self.assertRaises(SystemExit):
-            backintime.arg_parse(('restore', '--local-backup', '--no-local-backup'))
+            backintime.argParse(('restore', '--local-backup', '--no-local-backup'))
 
 if __name__ == '__main__':
     unittest.main()
